% A Simple 1d Surface Gravity Wave Model.
%
% This is a simple integration program to solve the differential equations:
% 
% d^2 eta/dt^2-c^2 d^2 eta/dx^2=0
%
% where c^2 is the phase speed of a surface gravity wave.  
%
% The default setting is arbitrary depth, but shallow water limits
% and deep water limits can be found either by changing 
% the depth in globalparms.m, 
% or by specifying these dispersion relations in tendencies.m
%
% Do not mess with rkparm.m or rk5.m, these are merely numerical routines.

% This file is the driver routine, and should be called from matlab
% to run the little model:  >>  integrater

% This initializes the Runge-Kutta parameters.  
% No need to edit rkparm.m
rkparm

% This initializes the other model parameters.  
% Feel free to add to globalparm.m
globalparm

% This initializes the optional parameters.  
% Feel free to change initopts.m
initopt

% This initializes the optional parameters.  
% Feel free to change initopts.m
initcond

% Initialization of arrays to save output for this run.
tsaves=zeros(1,maxsaves);
ysaves=zeros(length(y(:)),maxsaves);
outsaves=zeros(5,maxsaves);

% Save the initial values!
tsaves(:,1)=t;
ysaves(:,1)=y(:);

% This begins the clock for efficiency timing.
tic

% Beginning of run loop
while t<tmax
 steps=steps+1;

% This calls the Runge-Kutta timestepper
[ynew,hnew,outs]=rk5(t,h,y,opts,rk,herr);

% Update time, y, and adaptive timestep.
 t=t+h;
 y=ynew;
 
% The next timestep, we use either the suggested one from
% rk5, or the distance to the next save interval
 h=min([hnew,eps+saveint-mod(t,saveint)]);
 
%  For fixing CFL problems
% h=min(h,dtmin);

% Now check to see if we should save this step permanently
 if (mod(t,saveint)<2*eps)
  saves=saves+1;
  tsaves(saves)=t;
  ysaves(:,saves)=y(:);

% A little timer to see how long the whole run will last
% and a simple plotter of the run so far.
  if mod(saves,plotfreq)==0 
   [t tmax toc]
   plotter
  end
 end
end

plotend

