function [ynew,hnew,outs]=rk5(t,h,y,opts,rk,herr)
%% rk5 integrates y forward a time h given [yp]=tendencies(t,h,y,a,g,m,b,Km);
%% Where tendencies is supplied elsewhere.
%% t is time, h is timestep, y(:) are present values.
%%
%% rk5 is at most a Runge-Kutta 5th order scheme, with embedded 
%% lower order schemes from the Cash-Karp parameters.
%%
%% By comparing the higher and lower-order values, a time step
%% is automatically suggested.
%%
%% rkparm.m should be called first to set rk.
%% DO NOT EDIT

k=zeros(6,length(y(:)));
[yp]=tendencies(t+rk.ai(1)*h,h,y,opts);
k=h*yp(:);

for ii=2:6
 [yp,outs]=tendencies(t+rk.ai(ii)*h,h,y+reshape(k(:,1:ii-1)*rk.bij(1:ii-1,ii),size(y)),opts);
 k(:,ii)=h*yp(:);
end

y5=y(:)+k*rk.ci(:,5);

%Lower order estimates
y4=y(:)+k*rk.ci(:,4);
y3=y(:)+k*rk.ci(:,3);
y2=y(:)+k*rk.ci(:,2);
y1=y(:)+k*rk.ci(:,1);

% This is a time-step estimator, which seeks to optimize the maximum
% relative error between different order estimates.
hnew45=h*(herr/max(max(abs(y5-y4)),eps))^0.2;
hnew34=h*(herr/max(abs(y4-y3)))^0.25;
hnew23=h*(herr/max(abs(y3-y2)))^(1/3);
hnew12=h*(herr/max(abs(y2-y1)))^0.5;

hnew=hnew45;  %min([hnew12,hnew23,hnew34,hnew45]);
ynew=reshape(y5,size(y));
