function [yp,outs]=tendencies(t,h,y,opts)
% function [yp,outs]=tendencies(t,h,y,opts)
% This version of tendencies (dy/dt=yp) 
% provides the tendencies for the 1d surface gravity wave problem
%
% yp(1:lx)=d/dt(y(1:lx))
%
% yp(lx+1:end)=c^2 d^2/dx^2(y(1:lx))=ifft(c^2 k^2 fft(y(1:lx))) 
%
% For shorthand, yp is used to denote dy/dt
% also, the 1st half of the length of y is the surface height displacement
% while the second half is the d/dt of surface height displacement.

globalparm;

outs=[];

yp=zeros(size(y));

% This sets dy/dt to dy/dt
yp(1:lx)=y((lx+1):end);

% Now we fourier transform y.
yf=fft(y(1:lx));

% This is the wavenumber
k=4*pi*[0:lx/2-1 -lx/2:-1]./dx./lx;

%outs.cmax=sqrt(max([min(g.*k.*tanh(k*H)),g*H,min(g./k(k>0))]));

if opts.disp==0
 % This is the arbitrary depth disp. relation.  
 %  opts.disp==1 and opts.disp==2 are special limits of this one.
  yp((lx+1):end)=ifft(yf.*(-g.*k.*tanh(k*H)));
elseif opts.disp==1
 % This is the shallow water disp. relation
  yp((lx+1):end)=real(ifft(yf.*(-g*H.*k.^2)));
elseif opts.disp==2
 % This is the deep water disp. relation
  yp((lx+1):end)=real(ifft(yf.*(-g.*abs(k))));
end
